/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2004 Marco Pesenti Gritti
 * Copyright (C) 2008 Lucian Langa
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef __GECKO_UTILS_H__
#define __GECKO_UTILS_H__

G_BEGIN_DECLS

gboolean gecko_prefs_set_bool (const gchar *key, gboolean value);
gboolean gecko_prefs_set_string (const gchar *key, const gchar *value);
gboolean gecko_prefs_set_int (const gchar *key, const gint value);
gboolean       gecko_init         (void);
void           gecko_shutdown     (void);
void gecko_set_zoom (GtkWidget *moz, gfloat zoom);
gfloat gecko_get_zoom (GtkWidget *moz);
gint gecko_get_mouse_event_button(gpointer event);

G_END_DECLS

#endif /* __GECKO_UTILS_H__ */

